@@ -25,6 +25,19 @@ def dict_list2jsonline_file(data,output_dir,saved_file_name):
         for example in data:
             f.write(json.dumps(example,ensure_ascii=False)+"\n")
 
+def read_jsonline_file(file_path):
+    """读取json line file 文件
+
+    Args:
+        file_path (_type_): _description_
+    """
+    with open(file_path,"r") as f:
+        data = []
+        for line in f:
+            data.append(json.loads(line))
+        return data
+
+
 def train_dev_test_data2jsonline(data_dir,output_dir):
     file_name_list = ["dev","train","test"]
     for file_name in file_name_list:
