@@ -1,3 +1,4 @@
+from operator import index
 import pickle
 import json
 import string
@@ -7,11 +8,72 @@ import re
 from tqdm import tqdm
 import re
 from os.path import join as pjoin
+import pandas as pd
 
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(levelname)s %(message)s')
 en_char = string.ascii_lowercase+string.ascii_uppercase + " -_."
 
+
+def read_from_json(path):
+    return json.load(open(path,"r"))
+
+
+def write_to_json(data,path):
+    json.dump(
+        data,
+        open(path,"w",encoding="utf-8"),
+        indent=2,ensure_ascii=False
+    )
+
+def read_from_excel_to_dict(path,orient = "records"):
+    """_summary_
+
+    Args:
+        path (_type_): 路径
+        orient (str, optional): 返回的数据的格式. Defaults to "records".
+
+        orient : str {'dict', 'list', 'series', 'split', 'records', 'index'}
+                Determines the type of the values of the dictionary.
+
+                - 'dict' (default) : dict like {column -> {index -> value}}
+                - 'list' : dict like {column -> [values]}
+                - 'series' : dict like {column -> Series(values)}
+                - 'split' : dict like
+                {'index' -> [index], 'columns' -> [columns], 'data' -> [values]}
+                - 'records' : list like
+                [{column -> value}, ... , {column -> value}]
+                - 'index' : dict like {index -> {column -> value}}
+
+                Abbreviations are allowed. `s` indicates `series` and `sp`
+                indicates `split`.
+
+    Returns:
+        _type_: dict
+    """    
+    df = pd.read_excel(path)
+    data = df.to_dict(orient=orient)
+    return data
+
+def read_excel(path):
+    """读取excel 文件
+
+    Args:
+        path (_type_): _description_
+
+    Returns:
+        _type_: _description_
+    """    
+    df = pd.read_excel(path)
+    return df
+
+
+def get_torch_cuda_pip_cmd():
+    return '''
+    pip install torch==1.7.1+cu110  -f https://download.pytorch.org/whl/torch_stable.html
+    '''
+
+
 class PickleTool:
     """pickle 文件处理类
     """    
