@@ -2,6 +2,11 @@ import os
 from flask import Flask, request, jsonify
 from .translator import Translator
 
+"""
+基于huggingface 的MarianMTModel 构建了一个机器翻译微服务框架
+"""
+
+
 app = Flask(__name__)
 translator = Translator(os.environ.get("SOURCE_LANG"), os.environ.get("TARGET_LANG"), os.environ.get("MODEL_PATH"))
 
@@ -9,11 +14,14 @@ app.config["DEBUG"] = True # turn off in prod
 
 @app.route('/', methods=["GET"])
 def health_check():
-    """Confirms service is running"""
+    """检查服务是否运行
+
+    """    
     return "Machine translation service is up and running."
 
 @app.route('/lang_routes', methods = ["GET"])
 def get_lang_route():
+
     lang = request.args['lang']
     all_langs = translator.get_supported_langs()
     lang_routes = [l for l in all_langs if l[0] == lang]
@@ -21,11 +29,18 @@ def get_lang_route():
 
 @app.route('/supported_languages', methods=["GET"])
 def get_supported_languages():
+    """获取支持的翻译类型
+    """    
     langs = translator.get_supported_langs()
     return jsonify({"languages":langs})
 
 @app.route('/translate', methods=["POST"])
 def get_prediction():
+    """机器翻译服务
+
+    Returns:
+        _type_: _description_
+    """    
     text = request.json['text']
     translation = translator.translate(text)
     return jsonify({"translation":translation})
